pub struct Udf {
    run_txn: Func,
}

Fields

run_txn: Func

Implementations

source

impl Udf

source

pub fn instantiate<T>( store: impl AsContextMut<Data = T>, component: &Component, linker: &Linker<T> ) -> Result<(Self, Instance)>

Instantiates the provided module using the specified parameters, wrapping up the result in a structure that translates between wasm and the host.

source

pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Self>

Low-level creation wrapper for wrapping up the exports of the instance provided in this structure of wasm exports.

This function will extract exports from the instance defined within store and wrap them all up in the returned structure which can be used to interact with the wasm module.

source

pub fn run_txn<S: AsContextMut>( &self, store: S ) -> Result<Result<CommitDecision, String>>